package internal
import "github.com/nicksnyder/go-i18n/v2/internal"
Index ¶
Types ¶
type Template ¶
type Template struct {
Src string
LeftDelim string
RightDelim string
// contains filtered or unexported fields
}
Template stores the template for a string and a cached version of the parsed template if they are cacheable.
func (*Template) Execute ¶
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| internal/plural | Package plural provides support for pluralizing messages according to CLDR rules http://cldr.unicode.org/index/cldr-spec/plural-rules |
| internal/plural/codegen |
- Version
- v2.6.0 (latest)
- Published
- Apr 5, 2025
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 1 year ago –
Tools for package owners.